pub struct BlockchainConnectorConfig {
pub connection_sync_timeout: Duration,
pub sync_tolerance: usize,
pub tx_timeout_multiplier: u32,
}Expand description
Configuration of the HoprBlockchainConnector.
Fields
connection_sync_timeout: DurationMaximum time to wait for connection to complete.
Default is 30 seconds, minimum is 100 milliseconds.
sync_tolerance: usizePercentage of the total number of accounts and opened channels that must be received during a connection attempt to be successful.
Default is 90%, minimum is 1, maximum is 100.
tx_timeout_multiplier: u32Transaction waits for confirmation by multiplying chain’s blocktime, finality, and this multiplier. Set it to higher values if transactions are failing due to timeout at the client.
Default is 2, minimum is 1.